{ pkgs, inputs, ... }:

let 
	ddt4all = pkgs.stdenv.mkDerivation {
    	name = "ddt4all";
    	src = pkgs.fetchFromGitHub {
      		owner = "cedricp";
      		repo = "ddt4all";
      		rev = "master";
      		sha256 = "sha256-EX7cobgxM8/o4cRmfMMDSYG9X9Av6zmoWlSv1nzfl5o=";
    	};
    	
		nativeBuildInputs = [ pkgs.git ];
    	buildInputs = [ pkgs.stdenv.cc.cc.lib ];

    	installPhase = ''
      		mkdir -p $out/DDT4ALL
      		cp -r * $out/DDT4ALL
    	'';
  	};
in {
	imports = [ inputs.ags.homeManagerModules.default ];
	home = {
		activation.ddt4all = pkgs.lib.mkAfter ''
    		if [ ! -d "$HOME/DDT4ALL" ]; then
      			cp -r ${ddt4all}/DDT4ALL $HOME/DDT4ALL
    		fi
  		'';
    	packages = with pkgs; [
      		hyprland hyprlock hypridle hyprshot wl-clipboard cliphist swww
			lxqt.lxqt-policykit
			stdenv.cc.cc.lib

			pywal pywalfox-native

			(python3.withPackages (py: with py; [
				pywayland
			]))

			(birdtray.overrideAttrs (_: {
  				cmakeFlags = [ "-DOPT_THUNDERBIRD_CMDLINE=${thunderbird}/bin/thunderbird" ];
			}))

			jq
			bluez
			dconf
      		starship
			firefox-beta-bin
			thunderbird-bin
			element-desktop
			libreoffice-qt6-fresh
			gimp
			vscodium git nodejs
			fprintd
			cups
			fish
			anydesk
			fastfetch
			greetd.greetd greetd.tuigreet
			playerctl
			adwaita-icon-theme
			darkman
			android-tools
			filezilla
			bitwarden-desktop
			davinci-resolve
			mpv
			wget
			sshfs
    	];
  	};
}

